@@ -27,5 +27,6 @@ class WhiteListPoint(CreatePointMixin, ContractPoint):
     _create_contract = WhiteListCreateContract
 
 
-class WhiteListObjectPoint(DestroyPointMixin, ContractObjectPoint):
+class WhiteListObjectPoint(DestroyPointMixin, RetrievePointMixin, ContractObjectPoint):
     _point_id = WhiteListID()
+    _read_contract = WhiteListReadContract
